MathArgItem

Enum MathArgItem 

pub enum MathArgItem<'a> {
    Arg(Arg<'a>),
    Space(Space<'a>),
    Comma(char, &'a SyntaxNode),
    Semicolon(char, &'a SyntaxNode),
    LeftParen(char, &'a SyntaxNode),
    RightParen(char, &'a SyntaxNode),
}
Items at the top-level of a MathCall argument list that will be rendered into content if unparsing for a non-function.

This enum does not implement AstNode because the Semicolon variant requires extra context to convert correctly making it a likely footgun.

Variants



Arg(Arg<'a>)

A normal argument.



Space(Space<'a>)

A space between arguments and other punctuation.



Comma(char, &'a SyntaxNode)

A comma separating arguments.



Semicolon(char, &'a SyntaxNode)

A semicolon separating arguments. This excludes semicolons that end embedded code expressions.



LeftParen(char, &'a SyntaxNode)

The left paren at the start of the arguments.



RightParen(char, &'a SyntaxNode)

The right paren at the end of the arguments.