pub struct MathArg<'a> {
pub arg: Arg<'a>,
pub ends_in_semicolon: bool,
}Expand description
An argument in a MathCall for an actual function and whether it ends in
a semicolon.
Fields
arg: Arg<'a>The argument.
ends_in_semicolon: boolWhether the argument ends with a semicolon and should create two-dimensional args. This excludes semicolons that end embedded code expressions.