pub struct ModuleImport<'a>(/* private fields */);Expand description
A module import: import "utils.typ": a, b, c.
Implementations
Sourceimpl<'a> ModuleImport<'a>
impl<'a> ModuleImport<'a>
Sourcepub fn bare_name(self) -> Result<EcoString, BareImportError>
pub fn bare_name(self) -> Result<EcoString, BareImportError>
The name that will be bound for a bare import. This name must be statically known. It can come from:
- an identifier
- a field access
- a string that is a valid file path where the file stem is a valid identifier
- a string that is a valid package spec