Spread

Struct Spread 

pub struct Spread<'a>(/* private fields */);
A spread: ..x or ..x.at(0).

Implementations

Source

impl<'a> Spread<'a>

pub fn expr(self) -> Expr<'a>

The spread expression.

This should only be accessed if this Spread is contained in an ArrayItem, DictItem, or Arg.

pub fn sink_ident(self) -> Option<Ident<'a>>

The sink identifier, if present.

This should only be accessed if this Spread is contained in a Param or binding DestructuringItem.

pub fn sink_expr(self) -> Option<Expr<'a>>

The sink expressions, if present.

This should only be accessed if this Spread is contained in a DestructuringItem.