pub enum PathError {
Escapes,
Backslash,
}Expand description
An error that can occur on construction or modification of a
VirtualPath.
Variants
Escapes
The constructed or modified path would escape the root. This would
for instance, when trying to join .. to the path /.
Note that a path might still escape through symlinks.
Backslash
The path contains a backslash. This is not allowed as it leads to cross-platform compatibility hazards (since Windows uses backslashes as a path separator).