pub enum RealizeError {
Invalid(EcoString),
}Expand description
An error that can occur in VirtualPath::realize.
Variants
Invalid(EcoString)
A virtual path component was of a form that would be specially interpreted on the current platform as opposed to designating just a file or directory.
For example, this occurs when a path segments contains a drive letter
prefix on Windows (i.e. the virtual path /C:/System32/..) as Windows
interprets interior drive letters as resetting the path to the cwd (if
the cwd is on the current drive) or resetting the path to root (if the
cwd is on another drive).