pub enum VirtualizeError {
Path(PathError),
Invalid(EcoString),
Utf8,
}Expand description
An error that can occur in VirtualPath::virtualize.
Variants
Path(PathError)
A normal path error.
Invalid(EcoString)
A path component contained an invalid string. This should almost never occur under normal circumstances, but it could happen if some OS allows forward slashes or dots in path components.
Utf8
The file path contains non-UTF-8 encodable bytes.