DiagSpan

Struct DiagSpan 

pub struct DiagSpan { /* private fields */ }
The span of a diagnostic message. Either from a Typst source file or from a loaded external file.

Typst source spans may additionally contain a sub-range targeting just part of the overall range of the span.

When storing an external file range, the maximum value of the start/end is 2^46-1, larger values are saturated.

This type is stored compactly in 16 bytes and null-optimized, but can be expanded for easier usage as the DiagSpanKind enum via Self::get().

Implementations

Source

impl DiagSpan

pub const fn detached() -> Self

The detached diagnostic span that does not point into any file.

pub fn from_range(id: FileId, range: Range<usize>) -> Self

Create a new diagnostic span from an external file’s byte range instead of an internal span.

If either of the range’s parts exceeds the maximum value of 2^46-1, it will be saturated.

pub fn from_span(span: Span, sub_range: Option<SubRange>) -> Self

Create a new diagnostic span from a source span and optional sub-range.

The preferred interface for converting a Span into DiagSpan is using span.into(), which calls this with sub_range: None.

pub const fn is_detached(self) -> bool

Whether the diagnostic span is detached.

pub fn id(self) -> Option<FileId>

The id of the file the span points into.

Returns None if the span is detached.

pub fn or(self, other: Self) -> Self

Return other if self is detached and self otherwise.

pub fn get(self) -> DiagSpanKind

Unpack the diagnostic span into the variants of a DiagSpanKind for easier use.

To access a range, you may want to use WorldExt::range instead.