pub struct RootedPath { /* private fields */ }Expand description
A path in a specific virtual file system root.
This identifies a location in a project or package.
Implementations
Sourceimpl RootedPath
impl RootedPath
Sourcepub fn new(root: VirtualRoot, vpath: VirtualPath) -> Self
pub fn new(root: VirtualRoot, vpath: VirtualPath) -> Self
Create a rooted path from a root and a virtual path within the root.
Sourcepub fn root(&self) -> &VirtualRoot
pub fn root(&self) -> &VirtualRoot
The root this path resides in.
Sourcepub fn package(&self) -> Option<&PackageSpec>
👎Deprecated: use root instead
pub fn package(&self) -> Option<&PackageSpec>
use root instead
The package the path resides in, if any.
Sourcepub fn vpath(&self) -> &VirtualPath
pub fn vpath(&self) -> &VirtualPath
The absolute and normalized path to the file within the project or package.
Sourcepub fn map(&self, f: impl FnOnce(&VirtualPath) -> VirtualPath) -> Self
pub fn map(&self, f: impl FnOnce(&VirtualPath) -> VirtualPath) -> Self
Maps the virtual path while retaining the root.