pub struct SpanNumber(/* private fields */);Expand description
The unique number of a span within its Source. Known to
be within the range of Span::FULL.
This is mainly used externally as an input to the
Source::range method for efficiently finding the
byte range of a span.