pub struct SubRange { /* private fields */ }Expand description
A non-empty range targeting a smaller part of a spanned section of text.
Implementations
Sourceimpl SubRange
impl SubRange
Sourcepub fn new(start: usize, end: usize) -> Option<Self>
pub fn new(start: usize, end: usize) -> Option<Self>
Create a new sub-range. The given start and end must create a non-empty range.
If start or end are above a 2^32-1, they will be saturated.
Sourcepub fn to_relative(self) -> Range<usize>
pub fn to_relative(self) -> Range<usize>
Convert to a normal range relative to the spanned range.
Sourcepub fn to_absolute(self, offset: usize) -> Range<usize>
pub fn to_absolute(self, offset: usize) -> Range<usize>
Convert to a normal range at an offset.