pub struct SyntaxDiagnostic {
pub is_error: bool,
pub span: DiagSpan,
pub message: EcoString,
pub hints: EcoVec<Spanned<EcoString, DiagSpan>>,
}Expand description
A syntactical error or warning. This is mainly used by converting it to a
SourceDiagnostic during evaluation.
Fields
is_error: booltrue if the diagnostic is an error, false if it’s a warning.
span: DiagSpanThe span targeted by the diagnostic.
message: EcoStringThe main diagnostic message.
hints: EcoVec<Spanned<EcoString, DiagSpan>>Additional hints to the user indicating how this issue could be avoided or worked around.