VirtualPath

Struct VirtualPath 

pub struct VirtualPath(/* private fields */);
A path in a virtual file system.

Implementations

Source

impl VirtualPath

pub fn new(path: impl AsRef<str>) -> Result<Self, PathError>

Creates a new virtual path.

pub fn virtualize( root_path: &Path, path: &Path, ) -> Result<Self, VirtualizeError>

Creates a virtual path from a real path and a real root.

Returns None if the file path is not contained in the root (i.e. if root_path is not a lexical prefix of path). No file system operations are performed.

This is the single function that translates from a real path to a virtual path. Its counterpart is VirtualPath::realize.

pub fn realize(&self, root: &Path) -> Result<PathBuf, RealizeError>

Turns the virtual path into an actual file system path (where the project or package resides). You need to provide the appropriate root path, relative to which this path will be resolved.

This is the single function that translates from a virtual path to a real path. Its counterpart is VirtualPath::virtualize.

This function has platform-specific output and returns an error if the path contains platform-specific syntax that could lexically escape the root. Currently, no file system operations are performed, though this may change in the future.

This can be used in the implementations of World::source and World::file.

pub fn into_with_slash(self) -> EcoString

Extracts the path with a leading slash.

pub fn get_with_slash(&self) -> &str

Returns the path with a leading slash.

pub fn get_without_slash(&self) -> &str

Returns the path without a leading slash.

pub fn is_root(&self) -> bool

Whether this is the path /.

pub fn file_name(&self) -> Option<&str>

Returns the file name portion of the path.

pub fn file_stem(&self) -> Option<&str>

Returns the file name portion of the path without the extension.

pub fn extension(&self) -> Option<&str>

Returns the file extension of the path.

pub fn with_extension(&self, ext: &str) -> Self

Returns a modified path with an adjusted extension.

Panics

Panics if the resulting path segment would be invalid, e.g. because the extension contains a forward or backslash.

pub fn parent(&self) -> Option<Self>

Returns the path with its final component removed.

Returns None if the path is already at the root.

pub fn join(&self, path: &str) -> Result<Self, PathError>

Joins the given path to self.

pub fn relative_from(&self, base: &Self) -> EcoString

Expresses this path as a relative path from the given base path.

Source

impl VirtualPath

pub fn within_root(path: &Path, root: &Path) -> Option<Self>

👎Deprecated:

use virtualize with swapped arguments instead

Create a virtual path from a real path and a real root.

pub fn resolve(&self, root: &Path) -> Option<PathBuf>

👎Deprecated:

use realize instead

Resolve the virtual path relative to an actual file system root (where the project or package resides).

pub fn as_rootless_path(&self) -> &Path

👎Deprecated:

use get_without_slash instead

Get the underlying path without a leading / or \.

pub fn as_rooted_path(&self) -> &Path

👎Deprecated:

use get_with_slash instead

Get the underlying path with a leading / or \.