pub enum MathArgItem<'a> {
Arg(Arg<'a>),
Space(Space<'a>),
Comma(char, &'a SyntaxNode),
Semicolon(char, &'a SyntaxNode),
LeftParen(char, &'a SyntaxNode),
RightParen(char, &'a SyntaxNode),
}Expand description
Variants
Arg(Arg<'a>)
A normal argument.
Space(Space<'a>)
A space between arguments and other punctuation.
Comma(char, &'a SyntaxNode)
A comma separating arguments.
Semicolon(char, &'a SyntaxNode)
A semicolon separating arguments. This excludes semicolons that end embedded code expressions.
LeftParen(char, &'a SyntaxNode)
The left paren at the start of the arguments.
RightParen(char, &'a SyntaxNode)
The right paren at the end of the arguments.