ModuleImport

Struct ModuleImport 

pub struct ModuleImport<'a>(/* private fields */);
A module import: import "utils.typ": a, b, c.

Implementations

Source

impl<'a> ModuleImport<'a>

pub fn source(self) -> Expr<'a>

The module or path from which the items should be imported.

pub fn imports(self) -> Option<Imports<'a>>

The items to be imported.

pub fn bare_name(self) -> Result<EcoString, BareImportError>

The name that will be bound for a bare import. This name must be statically known. It can come from:

  • an identifier
  • a field access
  • a string that is a valid file path where the file stem is a valid identifier
  • a string that is a valid package spec
pub fn new_name(self) -> Option<Ident<'a>>

The name this module was assigned to, if it was renamed with as (renamed in import "..." as renamed).