pub struct Spread<'a>(/* private fields */);Expand description
A spread: ..x or ..x.at(0).
Implementations
Sourceimpl<'a> Spread<'a>
impl<'a> Spread<'a>
Sourcepub fn expr(self) -> Expr<'a>
pub fn expr(self) -> Expr<'a>
The spread expression.
This should only be accessed if this Spread is contained in an
ArrayItem, DictItem, or Arg.
Sourcepub fn sink_ident(self) -> Option<Ident<'a>>
pub fn sink_ident(self) -> Option<Ident<'a>>
The sink identifier, if present.
This should only be accessed if this Spread is contained in a
Param or binding DestructuringItem.