pub struct RangeMapper { /* private fields */ }Expand description
Remaps ranges.
Useful in combination with
SyntaxNode::synthesize_mapped to
have accurate error spans for source text that is non-consecutive in its
source file (for instance, Typst code in a doc comment with start-of-line
slashes).
Implementations
Sourceimpl RangeMapper
impl RangeMapper
Sourcepub fn new(
segments: impl IntoIterator<Item = Range<usize>>,
) -> Result<Self, EcoString>
pub fn new( segments: impl IntoIterator<Item = Range<usize>>, ) -> Result<Self, EcoString>
Creates a new range mapper.
The iterator should returns ranges in the original text that will be consecutively concatenated to produce the derived text.
Segments should be in order. (The start of a later range must not precede the end of an earlier range.)
Note that this representation implies that ranges can only ever increase in their start position and length when mapped.