SyntaxNode

Struct SyntaxNode 

pub struct SyntaxNode(/* private fields */);
A node in the untyped syntax tree.

Implementations

Source

impl SyntaxNode

pub fn is<'a, T: AstNode<'a>>(&'a self) -> bool

Whether the node can be cast to the given AST node.

pub fn cast<'a, T: AstNode<'a>>(&'a self) -> Option<T>

Try to convert the node to a typed AST node.

Source

impl SyntaxNode

pub fn leaf(kind: SyntaxKind, text: impl Into<EcoString>) -> Self

Create a new leaf node.

pub fn inner(kind: SyntaxKind, children: Vec<SyntaxNode>) -> Self

Create a new inner node with children.

pub fn error(error: SyntaxError, text: impl Into<EcoString>) -> Self

Create a new error node.

pub const fn placeholder(kind: SyntaxKind) -> Self

Create a dummy node of the given kind.

Panics if kind is SyntaxKind::Error.

pub fn kind(&self) -> SyntaxKind

The type of the node.

pub fn is_empty(&self) -> bool

Return true if the length is 0.

pub fn len(&self) -> usize

The byte length of the node in the source text.

pub fn span(&self) -> Span

The span of the node.

pub fn text(&self) -> &EcoString

The text of the node if it is a leaf or error node.

Returns the empty string if this is an inner node.

pub fn into_text(self) -> EcoString

Extract the text from the node.

Builds the string if this is an inner node.

pub fn children(&self) -> Iter<'_, SyntaxNode>

The node’s children.

pub fn erroneous(&self) -> bool

Whether the node or its children contain an error.

pub fn errors(&self) -> Vec<SyntaxError>

The error messages for this node and its descendants.

pub fn hint(&mut self, hint: impl Into<EcoString>)

Add a user-presentable hint if this is an error node.

pub fn synthesize(&mut self, span: Span)

Set a synthetic span for the node and all its descendants.

pub fn spanless_eq(&self, other: &Self) -> bool

Whether the two syntax nodes are the same apart from spans.